@@ -3,6 +3,7 @@ package Devel::NYTProf::FileInfo;    # fid_fileinfo
 use strict;
 
 use Carp;
+use Config;
 use List::Util qw(sum max);
 
 use Devel::NYTProf::Util qw(strip_prefix_from_paths trace_level);
@@ -275,12 +276,15 @@ sub collapse_sibling_evals {
 
     my $s_ltd = $survivor_fi->line_time_data; # XXX line only
     my $s_scl = $survivor_fi->sub_call_lines;
+    my %donor_fids;
 
     for my $donor_fi (@donors) {
         # copy data from donor to survivor_fi then delete donor
+        my $donor_fid = $donor_fi->fid;
+        $donor_fids{$donor_fid} = $donor_fi;
 
         warn sprintf "collapse_sibling_evals: processing donor fid %d: %s\n",
-                $donor_fi->fid, $donor_fi->filename
+                $donor_fid, $donor_fi->filename
             if trace_level() >= 3;
 
         # XXX nested evals not handled yet
@@ -294,7 +298,7 @@ sub collapse_sibling_evals {
 
             for my $si (@subs_defined) {
                 warn sprintf " - moving from fid %d: sub %s\n",
-                        $donor_fi->fid, $si->subname
+                        $donor_fid, $si->subname
                     if trace_level() >= 4;
                 $si->_alter_fileinfo($donor_fi, $survivor_fi);
                 warn sprintf " - moving done\n"
@@ -336,24 +340,30 @@ sub collapse_sibling_evals {
             my $s_tld_l = $s_ltd->[$line] ||= [];
             $s_tld_l->[$_] += $d_tld_l->[$_] for (0..@$d_tld_l-1);
             warn sprintf "%d:%d: @$s_tld_l from @$d_tld_l fid:%d\n",
-                $survivor_fi->fid, $line, $donor_fi->fid if 0;
+                $survivor_fi->fid, $line, $donor_fid if 0;
         }
 
-        push @{ $survivor_fi->meta->{merged_fids} }, $donor_fi->fid;
+        push @{ $survivor_fi->meta->{merged_fids} }, $donor_fid;
         ++$survivor_fi->meta->{merged_fids_src_varied}
             if $donor_fi->src_digest ne $survivor_fi->src_digest;
 
-        # remove eval from NYTP_FIDi_HAS_EVALS
-        if (my $eval_fis = $self->[NYTP_FIDi_HAS_EVALS()]) {
-            my $count = @$eval_fis;
-            @$eval_fis = grep { $_ != $donor_fi } @$eval_fis;
-            warn "_delete_eval missed" if @$eval_fis == $count;
-            # XXX needs to update NYTP_FIDi_SUBS_DEFINED NYTP_FIDi_SUBS_CALLED ?
-        }
-
         $donor_fi->_nullify;
     }
 
+    # remove donors from parent NYTP_FIDi_HAS_EVALS
+    if (my $eval_fis = $self->[NYTP_FIDi_HAS_EVALS()]) {
+        my %donors = map { +"$_" => 1 } @donors;
+        my $count = @$eval_fis;
+        @$eval_fis = grep { !$donors{$_} } @$eval_fis;
+        warn "_delete_eval mismatch"
+            if @$eval_fis != $count - @donors;
+    }
+
+    # update sawampersand_fid if it's one of the now-dead donors
+    if ($donor_fids{ $profile->attributes->{sawampersand_fid} || 0 }) {
+        $profile->attributes->{sawampersand_fid} = $survivor_fi->fid;
+    }
+
     # now the fid merging is complete...
     # look for any anon subs that are effectively duplicates
     # (ie have the same name except for eval seqn)
@@ -533,6 +543,9 @@ sub dump {
         NYTP_FIDi_FLAGS, NYTP_FIDi_FILESIZE, NYTP_FIDi_FILEMTIME
     ];
     $values[0] = $self->filename_without_inc;
+    # also remove possible remaining perl version seen in some cpantesters
+    # http://www.cpantesters.org/cpan/report/bf913910-bfdd-11df-a657-c9f38a00995b
+    $values[0] =~ s!^$Config{version}/!!o;
 
     printf $fh "%s[ %s ]\n", $prefix, join(" ", map { defined($_) ? $_ : 'undef' } @values);
 
