@@ -9,7 +9,6 @@ use ExtUtils::testlib;
 use Getopt::Long;
 use Test::More;
 use Data::Dumper;
-use File::Spec;
 use File::Temp qw(tempfile);
 use List::Util qw(shuffle);
 
@@ -27,15 +26,13 @@ use Devel::NYTProf::Run qw(perl_command_words);
 
 my $diff_opts = ($Config{osname} eq 'MSWin32') ? '-c' : '-u';
 
-eval { require BSD::Resource } if $ENV{NYTPROF_TEST_RUSAGE}; # experimental
-
 my %opts = (
     one          => $ENV{NYTPROF_TEST_ONE},
     profperlopts => $ENV{NYTPROF_TEST_PROFPERLOPTS} || '-d:NYTProf',
     html         => $ENV{NYTPROF_TEST_HTML},
     mergerdt     => $ENV{NYTPROF_TEST_MERGERDT}, # overkill, but handy
 );
-GetOptions(\%opts, qw/p=s I=s v|verbose d|debug html open profperlopts=s blocks=i leave=i use_db_sub=i savesrc=i compress=i one abort/)
+GetOptions(\%opts, qw/p=s I=s v|verbose d|debug html open profperlopts=s leave=i use_db_sub=i savesrc=i compress=i one abort/)
     or exit 1;
 
 $opts{v}    ||= $opts{d};
@@ -61,11 +58,10 @@ for my $opt (qw(trace)) {
 }
 
 
-my $text_extn_info = {
-    p     => { order => 10, tests => 1, },
-    rdt   => { order => 20, tests => ($opts{mergerdt}) ? 2 : 1, },
-    x     => { order => 30, tests => 3, },
-    calls => { order => 40, tests => 1, },
+my $tests_per_extn = {
+    p   => 1,
+    rdt => ($opts{mergerdt}) ? 2 : 1,
+    x   => 3
 };
 
 chdir('t') if -d 't';
@@ -79,10 +75,9 @@ my $bindir      = (grep {-d} qw(./blib/script ../blib/script))[0] || do {
     warn "Couldn't find blib/script directory, so using $bin";
     $bin;
 };
-my $nytprofcsv   = File::Spec->catfile($bindir, "nytprofcsv");
-my $nytprofcalls = File::Spec->catfile($bindir, "nytprofcalls");
-my $nytprofhtml  = File::Spec->catfile($bindir, "nytprofhtml");
-my $nytprofmerge = File::Spec->catfile($bindir, "nytprofmerge");
+my $nytprofcsv  = "$bindir/nytprofcsv";
+my $nytprofhtml = "$bindir/nytprofhtml";
+my $nytprofmerge= "$bindir/nytprofmerge";
 
 my $path_sep = $Config{path_sep} || ':';
 my $perl5lib = $opts{I} || join($path_sep, @INC);
@@ -97,51 +92,41 @@ if ($opts{one}) {           # for one quick test
     $opts{use_db_sub} = 0;
     $opts{savesrc}    = 1;
     $opts{compress}   = 1;
-    $opts{calls}      = 2;
-    $opts{blocks}     = 1;
 }
 
 # force savesrc off for perl 5.11.2 due to perl bug RT#70804
 $opts{savesrc} = 0 if $] eq "5.011002";
 
-my @test_opt_blocks     = (defined $opts{blocks})     ? ($opts{blocks})     : (1);
 my @test_opt_leave      = (defined $opts{leave})      ? ($opts{leave})      : (0, 1);
 my @test_opt_use_db_sub = (defined $opts{use_db_sub}) ? ($opts{use_db_sub}) : (0, 1);
 my @test_opt_savesrc    = (defined $opts{savesrc})    ? ($opts{savesrc})    : (0, 1);
 my @test_opt_compress   = (defined $opts{compress})   ? ($opts{compress})   : (0, 1);
-my @test_opt_calls      = (defined $opts{calls})      ? ($opts{calls})      : (0, 1, 2);
 
 sub mk_opt_combinations {
     my ($overrides) = @_;
 
     my @opt_combinations;
     my %seen;
-
-    for my $blocks (@test_opt_blocks) {
     for my $leave (@test_opt_leave) {
-    for my $use_db_sub (@test_opt_use_db_sub) {
-    for my $savesrc (@test_opt_savesrc) {
-    for my $compress (@test_opt_compress) {
-
-            my $o = {
-                start      => 'init',
-                slowops    => 2,
-                blocks     => $blocks,
-                leave      => $leave,
-                use_db_sub => $use_db_sub,
-                savesrc    => $savesrc,
-                compress   => $compress,
-                # we don't need to test the 'calls' opt with all other combinations
-                # so we fudge it here to be on most, but not all, of the time
-                calls      => (!!$savesrc + !!$compress), # 0|1|2
-                ($overrides) ? %$overrides : (),
-            };
-            my $key = join "\t", map { "$_=>$o->{$_}" } sort keys %$o;
-            next if $seen{$key}++;
-            push @opt_combinations, $o;
-
-    } } } } }
-
+        for my $use_db_sub (@test_opt_use_db_sub) {
+            for my $savesrc (@test_opt_savesrc) {
+                for my $compress (@test_opt_compress) {
+                    my $o = {
+                        start      => 'init',
+                        slowops    => 2,
+                        leave      => $leave,
+                        use_db_sub => $use_db_sub,
+                        savesrc    => $savesrc,
+                        compress   => $compress,
+                        ($overrides) ? %$overrides : (),
+                    };
+                    my $key = join "\t", map { "$_=>$o->{$_}" } sort keys %$o;
+                    next if $seen{$key}++;
+                    push @opt_combinations, $o;
+                }
+            }
+        }
+    }
     @opt_combinations = shuffle @opt_combinations;
     return \@opt_combinations;
 }
@@ -153,8 +138,6 @@ my %env_failed;
 sub do_foreach_opt_combination {
     my ($opt_combinations, $code) = @_;
 
-    my $rusage_start = get_rusage();
-
     COMBINATION:
     for my $env (@$opt_combinations) {
 
@@ -178,11 +161,10 @@ sub do_foreach_opt_combination {
         # did any tests fail?
         my $failed = (count_of_failed_tests() - $prev_failures) ? 1 : 0;
         # record what env settings may have influenced the failure
-        ++$env_influence{$_}{$env->{$_}}{$failed ? 'FAIL' : 'pass'}
+        ++$env_influence{$_}{$env->{$_}}{$failed ? 'fail' : 'pass'}
             for keys %$env;
         $env_failed{ $ENV{NYTPROF} } = $failed;
     }
-    report_rusage($rusage_start);
 }
 
 
@@ -194,21 +176,15 @@ sub report_env_influence {
     my @env_influence;
     for my $envvar (sort keys %env_influence) {
         my $variants = $env_influence{$envvar};
-
         local $Data::Dumper::Indent   = 0;
         local $Data::Dumper::Sortkeys = 1;
         local $Data::Dumper::Terse    = 1;
         local $Data::Dumper::Quotekeys= 0;
         local $Data::Dumper::Pair     = ' ';
         $variants->{$_} = Dumper($variants->{$_}) for keys %$variants;
-
-        # was there at least one failure?
-        next unless grep { /FAIL/ } values %$variants;
-
         my $v = (values %$variants)[0]; # use one as a reference
         # all the same?
         next if keys %$variants == grep { $_ eq $v } values %$variants;
-
         push @env_influence, sprintf "%15s: %s\n", $envvar,
             join ', ', map { "$_ => $variants->{$_}" } sort keys %$variants;
     }
@@ -248,17 +224,14 @@ sub run_test_group {
         croak "Can't determine test group";
     }
 
-    my @tests = grep { -f $_ }
-        map { "$group.$_" }
-        sort { $text_extn_info->{$a}{order} <=> $text_extn_info->{$b}{order} }
-        keys %$text_extn_info;
-    unlink <$group.*_new*>; # delete _new* files from previous run
+    my @tests = grep { -f $_ } map { "$group.$_" } sort keys %$tests_per_extn;
+    unlink <$group.*_new{,p}>; # delete _new and _newp files from previous run
 
     if ($opts{v}) {
         print "tests: @tests\n";
         print "perl: $perl\n";
         print "perl5lib: $perl5lib\n";
-        print "nytprofbin: $bindir\n";
+        print "nytprofcvs: $nytprofcsv\n";
     }
 
     plan skip_all => "No '$group.*' test files and no extra_test_code"
@@ -340,21 +313,12 @@ sub run_test {
         if ($opts{mergerdt}) { # run the file through nytprofmerge
             my $merged = "$profile_datafile.merged";
             my $merge_cmd = "$nytprofmerge -v --out=$merged $test_datafile";
-            warn "$merge_cmd\n";
             system($merge_cmd) == 0
                 or die "Error running $merge_cmd\n";
             verify_data($test, "$tag (merged)", $merged);
             unlink $merged;
         }
     }
-    elsif ($type eq 'calls') {
-        if ($env->{calls}) {
-            verify_calls_report($test, $tag, $test_datafile, $outdir);
-        }
-        else {
-            pass("no calls");
-        }
-    }
     elsif ($type eq 'x') {
         mkdir $outdir or die "mkdir($outdir): $!" unless -d $outdir;
         unlink <$outdir/*>;
@@ -406,11 +370,10 @@ sub run_perl_command {
 }
 
 
-sub profile { # TODO refactor to use run_perl_command()?
+sub profile {
     my ($test, $profile_datafile) = @_;
 
-    my @perl = perl_command_words(skip_sitecustomize => 1);
-    my $cmd = "@perl $opts{profperlopts} $test";
+    my $cmd = "$perl $opts{profperlopts} $test";
     return ok run_command($cmd), "$test runs ok under the profiler";
 }
 
@@ -428,23 +391,16 @@ sub verify_data {
     SKIP: {
         skip 'Expected profile data does not have VMS paths', 1
             if $^O eq 'VMS' and $test =~ m/test60|test14/i;
-        $profile->normalize_variables(1); # and options
+        $profile->normalize_variables;
         dump_profile_to_file($profile, $test.'_new', $test.'_newp');
-        is_file_content_same($test.'_new', $test, "$test match generated profile data for $tag");
+        my @got      = slurp_file($test.'_new'); chomp @got;
+        my @expected = slurp_file($test);        chomp @expected;
+        is_deeply(\@got, \@expected, "$test match generated profile data for $tag")
+            ? unlink($test.'_new')
+            : diff_files($test, $test.'_new', $test.'_newp');
     }
 }
 
-sub is_file_content_same {
-    my ($got_file, $exp_file, $testname) = @_;
-
-    my @got = slurp_file($got_file); chomp @got;
-    my @exp = slurp_file($exp_file); chomp @exp;
-
-    is_deeply(\@got, \@exp, $testname)
-        ? unlink($got_file)
-        : diff_files($exp_file, $got_file, $got_file."_patch");
-}
-
 
 sub dump_data_to_file {
     my ($profile, $file) = @_;
@@ -483,15 +439,6 @@ sub diff_files {
 }
 
 
-sub verify_calls_report {
-    my ($test, $tag, $profile_datafile, $outdir) = @_;
-    my $got_file = "${test}_new";
-    note "generating $got_file";
-    run_command("$nytprofcalls $profile_datafile -stable --calls > $got_file");
-    is_file_content_same($got_file, $test, "$test match generated calls data for $tag");
-}
-
-
 sub verify_csv_report {
     my ($test, $tag, $profile_datafile, $outdir) = @_;
 
@@ -540,7 +487,8 @@ sub verify_csv_report {
     # slow systems, e.g. cpan-testers running in cpu-starved virtual machines.
     # e.g., http://www.nntp.perl.org/group/perl.cpan.testers/2009/06/msg4227689.html
     my $max_time_overrun_percentage = ($automated_testing) ? 400 : 200;
-    my $max_time_underrun_percentage = 80;
+    # e.g., http://www.nntp.perl.org/group/perl.cpan.testers/2009/06/msg4230206.html
+    my $max_time_underrun_percentage = 90;
 
     my @accuracy_errors;
     $index = 0;
@@ -608,7 +556,7 @@ sub number_of_tests {
     my $total_tests = 0;
     for (@_) {
         next unless m/\.(\w+)$/;
-        my $tests = $text_extn_info->{$1}{tests};
+        my $tests = $tests_per_extn->{$1};
         warn "Unknown test type '$1' for test file '$_'\n" if not defined $tests;
         $total_tests += $tests if $tests;
     }
@@ -660,18 +608,6 @@ sub count_of_failed_tests {
 }
 
 
-sub get_rusage {
-    return scalar eval { BSD::Resource::getrusage(BSD::Resource::RUSAGE_CHILDREN()) };
-}
-
-sub report_rusage {
-    my $ru1 = shift or return;
-    my $ru2 = get_rusage();
-    my %diff;
-    $diff{$_} = $ru2->$_ - $ru1->$_ for (qw(maxrss));
-    warn " maxrss: $diff{maxrss}\n";
-}
-
 
 1;
 
